@@ -9,11 +9,9 @@ for IO related test cases.
 """
 
 import unittest, doctest
-
-from StringIO import StringIO
 import os, shutil, tempfile, copy
 
-from common_imports import etree, ElementTree, HelperTestCase, fileInTestDir, canonicalize
+from common_imports import StringIO, etree, ElementTree, HelperTestCase, fileInTestDir, canonicalize
 
 class ETreeTestCaseBase(unittest.TestCase):
     etree = None
@@ -393,7 +391,7 @@ class ETreeTestCaseBase(unittest.TestCase):
             result.append(el.tag)
         self.assertEquals(['one', 'two', 'three'], result)
 
-    def test_iteration2(self):
+    def test_iteration_empty(self):
         XML = self.etree.XML
         
         root = XML('<doc></doc>')
@@ -402,7 +400,7 @@ class ETreeTestCaseBase(unittest.TestCase):
             result.append(el.tag)
         self.assertEquals([], result)
 
-    def test_iteration3(self):
+    def test_iteration_text_only(self):
         XML = self.etree.XML
         
         root = XML('<doc>Text</doc>')
@@ -418,7 +416,22 @@ class ETreeTestCaseBase(unittest.TestCase):
         for elem in root:
             elem.tail = ''
 
-    def test_iteration4(self):
+    def test_iteration_reversed(self):
+        XML = self.etree.XML
+
+        try:
+            reversed(())
+        except NameError:
+            # before Python 2.4
+            return
+
+        root = XML('<doc><one/><two>Two</two>Hm<three/></doc>')
+        result = []
+        for el in reversed(root):
+            result.append(el.tag)
+        self.assertEquals(['three', 'two', 'one'], result)
+
+    def test_iteration_subelement(self):
         XML = self.etree.XML
 
         root = XML('<doc><one/><two>Two</two>Hm<three/></doc>')
@@ -431,7 +444,7 @@ class ETreeTestCaseBase(unittest.TestCase):
                 add = False
         self.assertEquals(['one', 'two', 'three', 'four'], result)
 
-    def test_iteration5(self):
+    def test_iteration_del_child(self):
         XML = self.etree.XML
 
         root = XML('<doc><one/><two>Two</two>Hm<three/></doc>')
@@ -441,7 +454,7 @@ class ETreeTestCaseBase(unittest.TestCase):
             del root[-1]
         self.assertEquals(['one', 'two'], result)
 
-    def test_iteration6(self):
+    def test_iteration_double(self):
         XML = self.etree.XML
 
         root = XML('<doc><one/><two/></doc>')
@@ -1787,6 +1800,14 @@ class ETreeTestCaseBase(unittest.TestCase):
         self.assertEquals(self._rootstring(t1), '<a><b/></a>')
         self.assertEquals(self._rootstring(t),  '<a><b/></a>')
 
+    def test_qname(self):
+        etree = self.etree
+        qname = etree.QName('myns', 'a')
+        a1 = etree.Element(qname)
+        a2 = etree.SubElement(a1, qname)
+        self.assertEquals(a1.tag, "{myns}a")
+        self.assertEquals(a2.tag, "{myns}a")
+
     def _writeElement(self, element, encoding='us-ascii'):
         """Write out element for comparison.
         """
